@@ -1,7 +1,7 @@
 package t::ToolSet::StrictWarn;
 use base 'ToolSet';
 
-ToolSet->set_strict(1);
-ToolSet->set_warnings(1);
+ToolSet->use_pragma( 'strict' );
+ToolSet->use_pragma( 'warnings' );
 
 1; # return true
