@@ -1,6 +1,6 @@
 package t::ToolSet::UseFeature;
 use base 'ToolSet';
 
-ToolSet->set_feature(":5.10");
+ToolSet->use_pragma( qw/feature :5.10/ );
 
 1; # return true
